//package com.prolog.cs.biz.outbound.controller;
//
//import com.prolog.cs.biz.outbound.model.dto.check.CheckConfirmDTO;
//import com.prolog.cs.biz.outbound.model.dto.check.CheckInfoDTO;
//import com.prolog.cs.biz.outbound.model.dto.check.CheckMakeRedDTO;
//import com.prolog.cs.biz.outbound.model.vo.check.InnerCheckBillV2VO;
//import com.prolog.cs.biz.outbound.model.vo.check.InnerCheckConfirmCheckVO;
//import com.prolog.cs.biz.outbound.service.InnerCheckV3Service;
//import com.prolog.framework.common.message.RestMessage;
//import com.prolog.framework.lock.annotation.RepeatOperationLock;
//import com.prolog.framework.log.aop.annotation.UserLog;
//import io.swagger.annotations.Api;
//import io.swagger.annotations.ApiImplicitParam;
//import io.swagger.annotations.ApiImplicitParams;
//import io.swagger.annotations.ApiOperation;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.web.bind.annotation.*;
//
//import java.util.List;
//
//@Api(tags = "复核任务")
//@RestController
//@RequestMapping("/inner/check/v3")
//public class InnerCheckV3Controller {
//
//    @Autowired
//    InnerCheckV3Service innerCheckService;
//
//
//    @UserLog
//    @RepeatOperationLock(timeOut = 1000)
//    @ApiOperation(value = "根据容器id获取订单信息")
//    @GetMapping("/container")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "containerCode", value = "容器id", required = true),
//            @ApiImplicitParam(name = "stationCode", value = "复核台编码"),
//            @ApiImplicitParam(name = "lcNo", value = "拼箱号"),
//            @ApiImplicitParam(name = "isDoubleCheck", value = "是否双人复核"),
//            @ApiImplicitParam(name = "warehouseId", value = "仓库Id")
//    })
//    public RestMessage<InnerCheckBillV2VO> getCheckInfoFromContainerId(
//            String containerCode,
//            String stationCode,
//            String billGroupId,
//            String lclNo,
//            Integer isDoubleCheck,
//            String warehouseId
//    ) {
//        return innerCheckService.getCurrentContainer(containerCode, stationCode,billGroupId,lclNo,isDoubleCheck,warehouseId);
//    }
//
//    @UserLog
//    @ApiOperation(value = "复核结果冲红2")
//    @PostMapping("/red")
//    public RestMessage<InnerCheckBillV2VO> makeCheckRed(@RequestBody CheckMakeRedDTO redDTO) {
//        return innerCheckService.makeCheckRed(redDTO);
//    }
//
//    @UserLog
//    @ApiOperation(value = "数量复核商品")
//    @PostMapping("/item/number")
//    @RepeatOperationLock(timeOut = 1000)
//    public RestMessage<InnerCheckBillV2VO> checkItemByNum(@RequestBody CheckInfoDTO checkInfoDTO) throws Exception{
//        return innerCheckService.checkItemByNum(checkInfoDTO);
//    }
//
//    @UserLog
//    @ApiOperation(value = "容器复核确认-拼箱对应的同一个票号（运单号）单的所有周转箱全部内复核完成")
//    @PostMapping("/confirm/check")
//    public RestMessage<InnerCheckConfirmCheckVO> confirmCheck(@RequestBody CheckConfirmDTO checkConfirmDTO) {
//        return innerCheckService.confirmCheck(checkConfirmDTO);
//    }
//
////    @UserLog
////    @ApiOperation(value = "容器复核确认")
////    @PostMapping("/confirm")
////    public RestMessage<InnerCheckConfirmCheckVO> containerCheckConfirm(@RequestBody CheckConfirmDTO checkConfirmDTO) {
////        return innerCheckService.containerCheckConfirm(checkConfirmDTO);
////    }
//}
